@@ -1,6 +1,6 @@
 ;;; phps-mode-test-integration.el --- Tests for integration -*- lexical-binding: t -*-
 
-;; Copyright (C) 2018-2023  Free Software Foundation, Inc.
+;; Copyright (C) 2018-2024  Free Software Foundation, Inc.
 
 
 ;;; Commentary:
@@ -150,7 +150,6 @@
    "<?php\n$str = <<<EOD\nExample of string\nspanning multiple lines\nusing heredoc syntax.\nEOD;\n\n/* More complex example, with variables. */\nclass foo\n{\n    var $foo;\n    var $bar;\n\n    function __construct()\n    {\n        $this->foo = 'Foo';\n        $this->bar = array('Bar1', 'Bar2', 'Bar3');\n    }\n}\n\n$foo = new foo();\n$name = 'MyName';\n\necho <<<EOT\nMy name is \"$name\". I am printing some $foo->foo.\nNow, I am printing some {$foo->bar[1]}.\nThis should print a capital 'A': \x41\nEOT;\n?>\n"
    "Integration-test 14 complex HEREDOC with removed heredoc delimiter semicolon"
    ;; (message "\nTokens: %s" phps-mode-lex-analyzer--tokens)
-   ;; (message "States: %s\n" phps-mode-lex-analyzer--states)
    (goto-char 88)
    (delete-char 1))
 
@@ -176,6 +175,15 @@
    (execute-kbd-macro (kbd "<return>"))
    (insert "echo 'was here';"))
 
+  (phps-mode-test--incremental-vs-intial-buffer
+   "<?php\nnamespace myNamespace\n{\n    class myClass\n    {\n        public function myFunction()\n        {\n            echo 'my statement';\n        }\n        public function mySecondFunction()\n        {\n            echo 'there';\n        }\n    }\n}\n"
+   "Integration-test 18 for regular PHP with namespaces, classes and functions using narrow-to-defun"
+   (goto-char 126)
+   (narrow-to-defun)
+   (execute-kbd-macro (kbd "<return>"))
+   (insert "echo 'was here';"))
+
+
   )
 
 (defun phps-mode-test-integration ()
